@@ -3,8 +3,7 @@ use warnings;
 
 =head1 NAME
 
-    Algorithm::Evolutionary::Individual::BitString - Classic bitstring individual for evolutionary computation; 
-                 usually called I<chromosome>
+Algorithm::Evolutionary::Individual::BitString - Classic bitstring individual for evolutionary computation; usually called I<chromosome>
 
 
 =head1 SYNOPSIS
@@ -37,9 +36,14 @@ use warnings;
     print $indi3->asXML() #Prints it as XML. See 
     print $indi3->as_yaml() #Change of convention, I know...
 
+    my $gene_size = 5;
+    my $min = -1;
+    my $range = 2;
+    my @decoded_vector = $indi3->decode( $gene_size, $min, $range);
+
 =head1 Base Class
 
-L<Algorithm::Evolutionary::Individual::String|Algorithm::Evolutionary::Individual::String>
+L<Algorithm::Evolutionary::Individual::String>
 
 =head1 DESCRIPTION
 
@@ -48,15 +52,17 @@ Bitstring Individual for a Genetic Algorithm. Used, for instance, in a canonical
 =cut
 
 package Algorithm::Evolutionary::Individual::BitString;
+
 use Carp;
 
-our ($VERSION) =  ( '$Revision: 2.1 $ ' =~ /(\d+\.\d+)/ );
+our ($VERSION) =  ( '$Revision: 3.4 $ ' =~ /(\d+\.\d+)/ );
 
 use base 'Algorithm::Evolutionary::Individual::String';
 
-use constant MY_OPERATORS => (Algorithm::Evolutionary::Individual::String::MY_OPERATORS, 
-			      qw(Algorithm::Evolutionary::Op::BitFlip Algorithm::Evolutionary::Op::Mutation )); 
- 
+use constant MY_OPERATORS => ( Algorithm::Evolutionary::Individual::String::MY_OPERATORS, 
+			       qw(Algorithm::Evolutionary::Op::BitFlip Algorithm::Evolutionary::Op::Mutation )); 
+
+use Algorithm::Evolutionary::Utils qw(decode_string); 
 
 =head1 METHODS
 
@@ -75,6 +81,20 @@ sub new {
   return $self;
 }
 
+=head2 from_string
+
+Similar to a copy ctor; creates a bitstring individual from a string. Will be deprecated soon
+
+=cut
+
+sub from_string  {
+  my $class = shift; 
+  my $chars = [ '0', '1' ];
+  my $self = 
+      Algorithm::Evolutionary::Individual::String::from_string( 'Algorithm::Evolutionary::Individual::BitString', $chars, @_ );
+  return $self;
+}
+
 =head2 set( $hash )
 
 Sets values of an individual; takes a hash as input. Keys are prepended an
@@ -89,16 +109,29 @@ sub set {
   $self->SUPER::set( $hash );
 }
 
+=head2 decode( $gene_size, $min, $range )
+
+Decodes to a vector, each one of whose components ranges between $min
+and $max. Returns that vector
+
+=cut
+
+sub decode {
+  my $self = shift;
+  my ( $gene_size, $min, $range ) = @_;
+  my $chromosome = $self->{'_str'};
+  return decode_string( $chromosome, $gene_size, $min, $range );
+}
 
 =head2 Copyright
   
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2009/02/04 20:43:14 $ 
-  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Individual/BitString.pm,v 2.1 2009/02/04 20:43:14 jmerelo Exp $ 
+  CVS Info: $Date: 2010/09/24 08:39:07 $ 
+  $Header: /media/Backup/Repos/opeal/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Individual/BitString.pm,v 3.4 2010/09/24 08:39:07 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 2.1 $
+  $Revision: 3.4 $
   $Name $
 
 =cut
