@@ -3,7 +3,7 @@ use warnings;
 
 =head1 NAME
 
-    Algorithm::Evolutionary::Op::GenerationalTerm  - Checks for termination of an algorithm.
+Algorithm::Evolutionary::Op::GenerationalTerm  - Checks for termination of an algorithm.
                  
 =head1 SYNOPSIS
 
@@ -15,7 +15,7 @@ L<Algorithm::Evolutionary::Op::Base|Algorithm::Evolutionary::Op::Base>
 
 =head1 DESCRIPTION
 
-    Checks for termination after a number of generations
+Checks for termination after a number of generations
 
 =head1 METHODS
 
@@ -23,14 +23,16 @@ L<Algorithm::Evolutionary::Op::Base|Algorithm::Evolutionary::Op::Base>
 
 package Algorithm::Evolutionary::Op::GenerationalTerm;
 
-our ($VERSION) = ( '$Revision: 2.2 $ ' =~ / (\d+\.\d+)/ ) ;
+our ($VERSION) = ( '$Revision: 3.0 $ ' =~ / (\d+\.\d+)/ ) ;
 
 use base 'Algorithm::Evolutionary::Op::Base';
 
-=head2 new( [$number_of_generations] )
+=head2 new( [$number_of_generations = 100] )
 
 Creates a new generational terminator:
-  my $gt = new Algorithm::Evolutionary::Op::GenerationalTerm 100; #apply will return false after 100 generations
+
+    my $gt = new Algorithm::Evolutionary::Op::GenerationalTerm 100; #apply will return false after 100 generations
+
 will make the C<apply> method return false after 100 calls
 
 =cut
@@ -43,12 +45,25 @@ sub new {
   return $self;
 }
 
+=head2 reset
+
+Resets the number of generations to 0
+
+=cut
+
+sub reset {
+  my $self = shift;
+  $self->{'counter'} =0;
+}
+
 
 =head2 apply()
 
 Checks if the counter has arrived to the allotted number of generations,
 returns false when it does. 
-  $gt->apply(); 
+
+    $gt->apply(); 
+
 will return C<false> when it has been run for the number of times it has
 been initialized to
 
@@ -67,8 +82,7 @@ L<Algorithm::Evolutionary::Op::FullAlgorithm> needs an object of this class to c
 for the termination condition. It's normally used alongside "generation-type"
 objects such as L<Algorithm::Evolutionary::Op::Easy>
 
-There are other options for termination conditions: L<Algorithm::Evolutionary::Op::NoChangeTerm|Algorithm::Evolutionary::Op::NoChangeTerm> and  
-L<Algorithm::Evolutionary::Op::DeltaTerm>.
+There are other options for termination conditions: L<Algorithm::Evolutionary::Op::NoChangeTerm|Algorithm::Evolutionary::Op::NoChangeTerm>,  L<Algorithm::Evolutionary::Op::Convergence_Terminator> and L<Algorithm::Evolutionary::Op::DeltaTerm>.
 
 
 =head1 Copyright
@@ -76,10 +90,10 @@ L<Algorithm::Evolutionary::Op::DeltaTerm>.
   This file is released under the GPL. See the LICENSE file included in this distribution,
   or go to http://www.fsf.org/licenses/gpl.txt
 
-  CVS Info: $Date: 2009/02/06 16:03:04 $ 
-  $Header: /cvsroot/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/GenerationalTerm.pm,v 2.2 2009/02/06 16:03:04 jmerelo Exp $ 
+  CVS Info: $Date: 2009/07/24 08:46:59 $ 
+  $Header: /media/Backup/Repos/opeal/opeal/Algorithm-Evolutionary/lib/Algorithm/Evolutionary/Op/GenerationalTerm.pm,v 3.0 2009/07/24 08:46:59 jmerelo Exp $ 
   $Author: jmerelo $ 
-  $Revision: 2.2 $
+  $Revision: 3.0 $
   $Name $
 
 =cut
